from setuptools import setup

install_requires = [
    "jgo>=0.4.0",
]

entry_points = {
    "console_scripts": [
        "mobie=mobie:main",
    ]
}

version = "4.0.2"

classifiers = [
    "License :: OSI Approved :: BSD License",
    "Programming Language :: Python :: 3 :: Only",
]

package_urls = {
    "Documentation": "https://mobie.github.io/",
}

setup(
    name="mobie",
    version=version,
    license_files=("LICENSE.txt",),
    author="Christian Tischer",
    author_email="christian.tischer@embl.de",
    maintainer="Christian Tischer",
    maintainer_email="christian.tischer@embl.de",
    description="Viewer for big multi-modal image data",
    url="https://github.com/mobie/mobie-viewer-fiji",
    package_urls=package_urls,
    packages=["mobie"],
    entry_points=entry_points,
    install_requires=install_requires,
    classifiers=classifiers,
)



import jgo.util
import argparse
from importlib.metadata import version
from functools import partial

_picocli_autocomplete = "picocli.AutoComplete"
_mobie_main_class = "org.embl.mobie.cmd.MoBIECmd"
_groupId = "org.embl.mobie"
_artifactId = "mobie-viewer-fiji"
_artifactVersion = version("mobie")


def launch_mobie(main_class, mobie_options):
    return jgo.util.main_from_endpoint(
        argv=mobie_options,
        primary_endpoint=f"{_groupId}:{_artifactId}",
        primary_endpoint_main_class=main_class,
        primary_endpoint_version=_artifactVersion,
    )


def main():
    p = argparse.ArgumentParser()
    sub = p.add_subparsers()
    mobie_project = sub.add_parser("project", add_help=False)
    mobie_project.set_defaults(func=partial(launch_mobie, "org.embl.mobie.cmd.ProjectCmd"))
    mobie_files = sub.add_parser("files", add_help=False)
    mobie_files.set_defaults(func=partial(launch_mobie, "org.embl.mobie.cmd.FilesCmd"))
    mobie_project = sub.add_parser("table", add_help=False)
    mobie_project.set_defaults(func=partial(launch_mobie, "org.embl.mobie.cmd.TableCmd"))
    mobie_files = sub.add_parser("hcs", add_help=False)
    mobie_files.set_defaults(func=partial(launch_mobie, "org.embl.mobie.cmd.HCSCmd"))

    # subparsers don't specify any options, everything is passed to MoBiE
    args, unknown = p.parse_known_args()
    args.func(mobie_options=unknown)
